=======
History
=======

0.1.4 (2017-12-15)
------------------

* Adds first template (german invoice)
* Adds exception catching for template rendering and hledger commands

0.1.3 (2017-12-15)
------------------

* Adds templating and some initial documenation. 

0.1.2 (2017-12-03)
------------------

* First release on PyPI.
